==> ember-cp-validations-5.0.0.tgz: package/README.md <==
# Ember CP Validations

[![Build Status](https://github.com/adopted-ember-addons/ember-cp-validations/actions/workflows/ci.yml/badge.svg)](https://github.com/adopted-ember-addons/ember-cp-validations/actions/workflows/ci.yml)
[![npm version](https://badge.fury.io/js/ember-cp-validations.svg)](http://badge.fury.io/js/ember-cp-validations)
[![Download Total](https://img.shields.io/npm/dt/ember-cp-validations.svg)](http://badge.fury.io/js/ember-cp-validations)
[![Ember Observer Score](http://emberobserver.com/badges/ember-cp-validations.svg)](http://emberobserver.com/addons/ember-cp-validations)

An EmberJS validation framework that is completely and utterly computed property based.

## Features

**No observers were used nor harmed while developing and testing this addon.**

- Lazily computed validations
- Ruby on rails inspired validators
- Support for Ember Data Models, Objects, Components, Services, etc.
- Support for nested models and objects
- Synchronous and asynchronous support
- Easily integrated with Ember Data's [DS.Errors](http://emberjs.com/api/data/classes/DS.Errors.html)
- No observers. Seriously... there are none. Like absolutely zero....
- Custom validators
- I18n support
- Debounceable validations
- Warning validations

[![Introduction to Ember CP Validations](https://cloud.githubusercontent.com/assets/2922250/21854491/ebda55b8-d7e8-11e6-8d13-00dff93be8d8.png)](https://embermap.com/video/ember-cp-validations)

You can also learn more by watching this Global Ember Meetup talk:

[![Introduction to ember-cp-validations](https://i.vimeocdn.com/video/545445254.png?mw=1920&mh=1080&q=70)](https://vimeo.com/146857699)

## Installation

```shell
ember install ember-cp-validations
```

## Upgrading to 4.x

If you are upgrading from 3.x to 4.x, please checkout the [upgrading documentation](UPGRADING.md).

## Helpful Links

- ### [Live Demo](http://adopted-ember-addons.github.io/ember-cp-validations)

- ### Documentation

  - [4.x](http://adopted-ember-addons.github.io/ember-cp-validations/docs)
  - [3.x](https://rawgit.com/adopted-ember-addons/ember-cp-validations/c4123c983e54f24dd790ffa1bad66cfdf2f47ec6/docs/index.html)

- ### [Changelog](CHANGELOG.md)

## Looking for help?

- If it is a bug [please open an issue on GitHub](http://github.com/adopted-ember-addons/ember-cp-validations/issues).
- Ask a question in the `#e-cp-validations` channel at the [Ember.js Community Slack](https://embercommunity.slack.com)

==> ember-cp-validations-6.0.1.tgz: package/README.md <==
# Ember CP Validations

[![Build Status](https://github.com/adopted-ember-addons/ember-cp-validations/actions/workflows/ci.yml/badge.svg)](https://github.com/adopted-ember-addons/ember-cp-validations/actions/workflows/ci.yml)
[![npm version](https://badge.fury.io/js/ember-cp-validations.svg)](http://badge.fury.io/js/ember-cp-validations)
[![Download Total](https://img.shields.io/npm/dt/ember-cp-validations.svg)](http://badge.fury.io/js/ember-cp-validations)
[![Ember Observer Score](http://emberobserver.com/badges/ember-cp-validations.svg)](http://emberobserver.com/addons/ember-cp-validations)

An EmberJS validation framework that is completely and utterly computed property based.

## Compatibility

| Addon | Ember   | Node    |
|-------|---------|---------|
| 6.x   | >= 3.28 | >= 14.x |
| 5.x   | >= 3.28 | >= 12.x |
| 4.x   | <= 3.28 | >= 12.x |


## Features

**No observers were used nor harmed while developing and testing this addon.**

- Lazily computed validations
- Ruby on rails inspired validators
- Support for Ember Data Models, Objects, Components, Services, etc.
- Support for nested models and objects
- Synchronous and asynchronous support
- Easily integrated with Ember Data
- No observers. Seriously... there are none. Like absolutely zero....
- Custom validators
- I18n support
- Debounceable validations
- Warning validations

[![Introduction to Ember CP Validations](https://cloud.githubusercontent.com/assets/2922250/21854491/ebda55b8-d7e8-11e6-8d13-00dff93be8d8.png)](https://embermap.com/video/ember-cp-validations)

You can also learn more by watching this Global Ember Meetup talk:

[![Introduction to ember-cp-validations](https://i.vimeocdn.com/video/545445254.png?mw=1920&mh=1080&q=70)](https://vimeo.com/146857699)

## Installation

```shell
ember install ember-cp-validations
```

## Upgrading to 4.x

If you are upgrading from 3.x to 4.x, please checkout the [upgrading documentation](UPGRADING.md).

## Helpful Links

- ### [Live Demo](http://adopted-ember-addons.github.io/ember-cp-validations)

- ### Documentation

  - [4.x](http://adopted-ember-addons.github.io/ember-cp-validations/docs)
  - [3.x](https://rawgit.com/adopted-ember-addons/ember-cp-validations/c4123c983e54f24dd790ffa1bad66cfdf2f47ec6/docs/index.html)

- ### [Changelog](CHANGELOG.md)

## Looking for help?

- If it is a bug [please open an issue on GitHub](http://github.com/adopted-ember-addons/ember-cp-validations/issues).
- Ask a question in the `#e-cp-validations` channel at the [Ember.js Community Slack](https://embercommunity.slack.com)
